==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>گروه مهم :</b>توصيه ميشود كه يك كليد-واژه در اين گروه انتخاب كنيد ',
	'avis_doublon_mot_cle' => 'يك كلمه با اين تيتر وجود دارد. آيا اطمينان داريد كه مي‌خواهيد همان را ايجاد كنيد?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'گردانندگان سايت',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'نويسندگان',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'بازديد كنندهاى سايت همگانى هنگامى كه پيامى در سخنگاه ميفرستند',

	// C
	'creer_et_associer_un_mot' => 'ساختن و چسباندن يك كليدواژه',

	// I
	'icone_creation_groupe_mots' => 'يك گروه واژه نو بسازيد',
	'icone_creation_mots_cles' => 'يك واژه-كليد نو بسازيد',
	'icone_modif_groupe_mots' => 'اين گروه از واژه ها را اصلاح كنيد',
	'icone_modifier_mot' => 'اصلاح اين كليدواژه',
	'icone_mots_cles' => 'واژه-كليدها',
	'icone_supprimer_groupe_mots' => 'اين گروه را حذف كنيد',
	'icone_voir_groupe_mots' => 'اين گروه واژه را بنگريد',
	'icone_voir_tous_mots_cles' => 'همه واژه-كليدها را نگاه كنيد',
	'info_1_groupe_mots' => '1 گروه واژه',
	'info_articles_lies_mot' => 'مقالات مربوط به اين واژه-كليد',
	'info_aucun_groupe_mots' => 'هيچ گروه واژه',
	'info_aucun_mot_cle' => 'هيچ كليد-واژه‌اي موجود نيست',
	'info_changer_nom_groupe' => ':نام اين گروه را تغيير دهيد',
	'info_creation_mots_cles' => 'واژه-كليد هاى سايت را اينجا بسازيد',
	'info_dans_groupe' => ':درون گروه',
	'info_delet_mots_cles' => ' شما درخواست حذف اين واژه-كليد را كرده ايد<b>@titre_mot@</b> (@type_mot@).شما بايد اين حذف را تأئيد كنيد، زيرا اين واژه-كليد به اين متن مرتبط است :<b>@texte_lie@</b>',
	'info_groupe_important' => 'گروه مهم',
	'info_modifier_mot' => 'اصلاح كليدواژه:',
	'info_mots_cles' => 'واژه-كليدها',
	'info_mots_cles_association' => ': واژه-كليدهاى اين گروه ميتوانند سهيم بشوند',
	'info_nb_groupe_mots' => '@nb@ گروه واه',
	'info_oui_suppression_mot_cle' => 'ميخواهم اين كليد-واژه را براى هميشه حذف كنم',
	'info_question_mots_cles' => 'آيا ميخواهيد از واژه-كليدها در سايتتان استفاد كنيد ؟',
	'info_qui_attribue_mot_cle' => ':ميتوان واژه هاى اين گروه را نسبت داد به ',
	'info_remplacer_mot' => 'جايگزين "@titre@"',
	'info_retirer_mot' => 'اين واژه را برداريد',
	'info_retirer_mots' => 'تمام واژه ها را برداريد',
	'info_rubriques_liees_mot' => 'بخش هاى مربوط به اين واژه-كليد',
	'info_selection_un_seul_mot_cle' => 'نميتوان هر دفعه بيش از يك كليد-واژه در اين گروه انتخاب كرد.',
	'info_supprimer_mot' => 'اين  واژه را حذف كنيد',
	'info_titre_mot_cle' => 'نام يا عنوان كليد-واژه',
	'info_un_mot' => 'يك واژه, هر بار',
	'item_ajout_mots_cles' => 'افزودن واژه-كليدها را به سخنگاه مجاز كنيد',
	'item_non_ajout_mots_cles' => 'استفاده از واژه-كليدها را در سخنگاه ممنوع كنيد',
	'item_non_utiliser_config_groupe_mots_cles' => 'از پيكر بندى پيشرفته گروههاى واژه-كليدها استفاده نكنيد',
	'item_non_utiliser_mots_cles' => 'از واژه-كليدها استفاده نكنيد',
	'item_utiliser_config_groupe_mots_cles' => 'از پيكر بندى پيشرفته گروههاى واژه-كليدها استفاده كنيد',
	'item_utiliser_mots_cles' => 'از واژه-كليدها استفاده كنيد',

	// L
	'lien_ajouter_mot' => 'افزودن اين كليد-واژه',
	'logo_groupe' => 'لوگوي اين گروه',
	'logo_mot_cle' => 'درج علامت (لوگو) براى كليد-واژه',

	// T
	'texte_config_groupe_mots_cles' => 'آيا مايليد پيكربندى پيشرفته كليد-واژه ها را، مثلاً نشاند دادن اينكه از يك گروه يك كليد‌واژه را مي‌تواتن انتخاب كرد،كه يك گروه مهم است، فعال كنيد؟ ...',
	'texte_mots_cles' => 'واژه-كليدها امكان ساخت پيوندهاى مربوط به يك موضوع را مستقل از مكانشان در بخشها، به مقالاتتان ميدهد. شما ميتوانيد همچنين سايتتان را توسعه دهيد، يا حتى براى معرفى مقالات در اسكلتهايتان استفاده كنيد.',
	'texte_mots_cles_dans_forum' => 'آيا مايليد كه بازديدكنندگان از كليد-واژه هاى انتخابى در سخنگاه سايت همگانى استفاده كنند؟(توجه : استفاده درست از اين گزينش نسبتا پيچيده ميباشد)',
	'texte_nouveau_mot' => 'واژه جديد',
	'titre_config_groupe_mots_cles' => 'پيكربندى گروه هاى واژه-كليدها',
	'titre_gauche_mots_edit' => 'واژه شماره :',
	'titre_groupe_mots' => 'گروه كليدواژه‌ها',
	'titre_groupe_mots_numero' => 'گروه نمره واژه‌ها:',
	'titre_groupes_mots' => 'گروه‌هاي كليد‌واژه‌ها',
	'titre_mots_cles_dans_forum' => 'واژه-كليدهاى سخنگاه سايت همگانى',
	'titre_mots_tous' => 'واژه-كليدها',
	'titre_nouveau_groupe' => 'گروه جديد',
	'titre_objets_lies_mot' => 'وابسته به اين كليدواژه:',
	'titre_page_mots_tous' => 'واژه-كليدها'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>گروه مهم :</b>توصيه ميشود كه يك كليد-واژه در اين گروه انتخاب كنيد ',
	'avis_doublon_mot_cle' => 'يك كلمه با اين تيتر وجود دارد. آيا اطمينان داريد كه مي‌خواهيد همان را ايجاد كنيد?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'گردانندگان سايت',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'نويسندگان',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'بازديد كنندهاى سايت همگانى هنگامى كه پيامى در سخنگاه ميفرستند',

	// C
	'creer_et_associer_un_mot' => 'ساختن و چسباندن يك كليدواژه',

	// I
	'icone_creation_groupe_mots' => 'يك گروه واژه نو بسازيد',
	'icone_creation_mots_cles' => 'يك واژه-كليد نو بسازيد',
	'icone_modif_groupe_mots' => 'اين گروه از واژه ها را اصلاح كنيد',
	'icone_modifier_mot' => 'اصلاح اين كليدواژه',
	'icone_mots_cles' => 'واژه-كليدها',
	'icone_supprimer_groupe_mots' => 'اين گروه را حذف كنيد',
	'icone_voir_groupe_mots' => 'اين گروه واژه را بنگريد',
	'icone_voir_tous_mots_cles' => 'همه واژه-كليدها را نگاه كنيد',
	'info_1_groupe_mots' => '1 گروه واژه',
	'info_articles_lies_mot' => 'مقالات مربوط به اين واژه-كليد',
	'info_aucun_groupe_mots' => 'هيچ گروه واژه',
	'info_aucun_mot_cle' => 'هيچ كليد-واژه‌اي موجود نيست',
	'info_changer_nom_groupe' => ':نام اين گروه را تغيير دهيد',
	'info_creation_mots_cles' => 'واژه-كليد هاى سايت را اينجا بسازيد',
	'info_dans_groupe' => ':درون گروه',
	'info_delet_mots_cles' => ' شما درخواست حذف اين واژه-كليد را كرده ايد<b>@titre_mot@</b> (@type_mot@).شما بايد اين حذف را تأئيد كنيد، زيرا اين واژه-كليد به اين متن مرتبط است :<b>@texte_lie@</b>',
	'info_groupe_important' => 'گروه مهم',
	'info_modifier_mot' => 'اصلاح كليدواژه:',
	'info_mots_cles' => 'واژه-كليدها',
	'info_mots_cles_association' => ': واژه-كليدهاى اين گروه ميتوانند سهيم بشوند',
	'info_nb_groupe_mots' => '@nb@ گروه واه',
	'info_oui_suppression_mot_cle' => 'ميخواهم اين كليد-واژه را براى هميشه حذف كنم',
	'info_question_mots_cles' => 'آيا ميخواهيد از واژه-كليدها در سايتتان استفاد كنيد ؟',
	'info_qui_attribue_mot_cle' => ':ميتوان واژه هاى اين گروه را نسبت داد به ',
	'info_remplacer_mot' => 'جايگزين "@titre@"',
	'info_retirer_mot' => 'اين واژه را برداريد',
	'info_retirer_mots' => 'تمام واژه ها را برداريد',
	'info_rubriques_liees_mot' => 'بخش هاى مربوط به اين واژه-كليد',
	'info_selection_un_seul_mot_cle' => 'نميتوان هر دفعه بيش از يك كليد-واژه در اين گروه انتخاب كرد.',
	'info_supprimer_mot' => 'اين  واژه را حذف كنيد',
	'info_titre_mot_cle' => 'نام يا عنوان كليد-واژه',
	'info_un_mot' => 'يك واژه, هر بار',
	'item_ajout_mots_cles' => 'افزودن واژه-كليدها را به سخنگاه مجاز كنيد',
	'item_non_ajout_mots_cles' => 'استفاده از واژه-كليدها را در سخنگاه ممنوع كنيد',
	'item_non_utiliser_config_groupe_mots_cles' => 'از پيكر بندى پيشرفته گروههاى واژه-كليدها استفاده نكنيد',
	'item_non_utiliser_mots_cles' => 'از واژه-كليدها استفاده نكنيد',
	'item_utiliser_config_groupe_mots_cles' => 'از پيكر بندى پيشرفته گروههاى واژه-كليدها استفاده كنيد',
	'item_utiliser_mots_cles' => 'از واژه-كليدها استفاده كنيد',

	// L
	'lien_ajouter_mot' => 'افزودن اين كليد-واژه',
	'logo_groupe' => 'لوگوي اين گروه',
	'logo_mot_cle' => 'درج علامت (لوگو) براى كليد-واژه',

	// T
	'texte_config_groupe_mots_cles' => 'آيا مايليد پيكربندى پيشرفته كليد-واژه ها را، مثلاً نشاند دادن اينكه از يك گروه يك كليد‌واژه را مي‌تواتن انتخاب كرد،كه يك گروه مهم است، فعال كنيد؟ ...',
	'texte_mots_cles' => 'واژه-كليدها امكان ساخت پيوندهاى مربوط به يك موضوع را مستقل از مكانشان در بخشها، به مقالاتتان ميدهد. شما ميتوانيد همچنين سايتتان را توسعه دهيد، يا حتى براى معرفى مقالات در اسكلتهايتان استفاده كنيد.',
	'texte_mots_cles_dans_forum' => 'آيا مايليد كه بازديدكنندگان از كليد-واژه هاى انتخابى در سخنگاه سايت همگانى استفاده كنند؟(توجه : استفاده درست از اين گزينش نسبتا پيچيده ميباشد)',
	'texte_nouveau_mot' => 'واژه جديد',
	'titre_config_groupe_mots_cles' => 'پيكربندى گروه هاى واژه-كليدها',
	'titre_gauche_mots_edit' => 'واژه شماره :',
	'titre_groupe_mots' => 'گروه كليدواژه‌ها',
	'titre_groupe_mots_numero' => 'گروه نمره واژه‌ها:',
	'titre_groupes_mots' => 'گروه‌هاي كليد‌واژه‌ها',
	'titre_mots_cles_dans_forum' => 'واژه-كليدهاى سخنگاه سايت همگانى',
	'titre_mots_tous' => 'واژه-كليدها',
	'titre_nouveau_groupe' => 'گروه جديد',
	'titre_objets_lies_mot' => 'وابسته به اين كليدواژه:',
	'titre_page_mots_tous' => 'واژه-كليدها'
);

?>
